@@ -18,10 +18,26 @@ GType gcr_certificate_chain_status_get_type (void) G_GNUC_CONST;
 GType gcr_certificate_chain_flags_get_type (void) G_GNUC_CONST;
 #define GCR_TYPE_CERTIFICATE_CHAIN_FLAGS (gcr_certificate_chain_flags_get_type ())
 
+/* enumerations from "gcr-certificate-request.h" */
+GType gcr_certificate_request_format_get_type (void) G_GNUC_CONST;
+#define GCR_TYPE_CERTIFICATE_REQUEST_FORMAT (gcr_certificate_request_format_get_type ())
+
 /* enumerations from "gcr-deprecated-base.h" */
 GType gcr_importer_prompt_behavior_get_type (void) G_GNUC_CONST;
 #define GCR_TYPE_IMPORTER_PROMPT_BEHAVIOR (gcr_importer_prompt_behavior_get_type ())
 
+/* enumerations from "gcr-prompt.h" */
+GType gcr_prompt_reply_get_type (void) G_GNUC_CONST;
+#define GCR_TYPE_PROMPT_REPLY (gcr_prompt_reply_get_type ())
+
+/* enumerations from "gcr-system-prompt.h" */
+GType gcr_system_prompt_error_get_type (void) G_GNUC_CONST;
+#define GCR_TYPE_SYSTEM_PROMPT_ERROR (gcr_system_prompt_error_get_type ())
+
+/* enumerations from "gcr-system-prompter.h" */
+GType gcr_system_prompter_mode_get_type (void) G_GNUC_CONST;
+#define GCR_TYPE_SYSTEM_PROMPTER_MODE (gcr_system_prompter_mode_get_type ())
+
 /* enumerations from "gcr-types.h" */
 GType gcr_data_error_get_type (void) G_GNUC_CONST;
 #define GCR_TYPE_DATA_ERROR (gcr_data_error_get_type ())
